@@ -64,14 +64,22 @@ def countrycode_from_swiftcode(swiftcode: str):
     The SWIFT code is 8 or 11 characters, made up of:
 
     4 letters: institution code or bank code.
-    2 letters: ISO 3166-1 alpha-2 country code (exceptionally, SWIFT has assigned the code XK to Republic of Kosovo, which does not have an ISO 3166-1 country code)
+    2 letters: ISO 3166-1 alpha-2 country code (exceptionally,
+    SWIFT has assigned the code XK to Republic of Kosovo,
+    which does not have an ISO 3166-1 country code)
     2 letters or digits: location code
-        if the second character is "0", then it is typically a test BIC as opposed to a BIC used on the live network.
-        if the second character is "1", then it denotes a passive participant in the SWIFT network
-        if the second character is "2", then it typically indicates a reverse billing BIC, where the recipient pays for the message as opposed to the more usual mode whereby the sender pays for the message.
+        if the second character is "0",
+        then it is typically a test BIC as opposed to a
+        BIC used on the live network.  if the second character is "1",
+        then it denotes a passive participant in the SWIFT network
+        if the second character is "2",
+        then it typically indicates a reverse billing BIC,
+        where the recipient pays for the message as opposed to the more usual
+        mode whereby the sender pays for the message.
     3 letters or digits: branch code, optional ('XXX' for primary office)
 
-    Where an eight digit code is given, it may be assumed that it refers to the primary office.
+    Where an eight digit code is given,
+    it may be assumed that it refers to the primary office.
 
     """
     if not isvalid_swiftcode(swiftcode):
